ORM – object relational mapping — summer 0.7.8 documentation

# ORM – object relational mapping

## sf – ORM session factory

Module `sf` defines `SessionFactory` class which is central point for your ORM mapping and SQL database access providing connections to database.

## dao – ORM data access object support

Provides DAO support.

Base `Dao` class provides access to `Dao.session()` and py:meth:Dao.connection properties.

That means that inside any DAO object subclassed from `Dao` you can access current (thread-bound) SqlAlchemy session simply by accessing `Dao.session()` and direct connection to database by accessing `Dao.connection()`.

Much more interesting is `EntityDao` class which is inteded to be used as a base DAO class for your `summer.domain.Entity`.